@@ -8,10 +8,11 @@ from .tool_executor import (
     SecurityError,
     TimeoutError,
     ExecutorConfig,
-    ExecutorMetrics,
+    ToolExecutorStats,
     get_executor,
     validate_input,
     cache_result,
+    cache_result_with_strategy,
     run_in_executor,
     measure_execution_time,
     sanitize_input
@@ -25,10 +26,11 @@ __all__ = [
     'SecurityError',
     'TimeoutError',
     'ExecutorConfig',
-    'ExecutorMetrics',
+    'ToolExecutorStats',
     'get_executor',
     'validate_input',
     'cache_result',
+    'cache_result_with_strategy',
     'run_in_executor',
     'measure_execution_time',
     'sanitize_input'
